@@ -782,12 +782,16 @@ ModSummary.lmrob <- function (x, conf.level = 0.95, ...) {
 }
 
 
-ModSummary.glm <- function(x, conf.level=0.95, ...){
+ModSummary.glm <- function(x, conf.level=0.95, use.profile = TRUE, ...){
   
   sumry <- summary(x)
   
   # coefx <- cbind(summod$coefficients, confint(x, level=conf.level), stbeta=c(NA, StdCoeff(x)))
-  ci <- confint(x, level=conf.level)
+  if(use.profile)
+    ci <- confint(x, level=conf.level)
+  else 
+    ci <- confint.default(x, level=conf.level)
+  
   if(nrow(sumry$coefficients)==1)
     ci <- t(ci)
   coefx <- data.frame(row.names(sumry$coefficients), sumry$coefficients, ci,
@@ -1323,6 +1327,11 @@ PseudoR2 <- function(x, which = NULL) {
   # fuer logit Korrektur https://langer.soziologie.uni-halle.de/pdf/papers/rc33langer.pdf
   
   # check with pscl::pR2(x); rcompanion::nagelkerke(x)
+  #       or with  library(blorr)
+  #                c(blr_rsq_mcfadden(r.glm), 
+  #                  blr_rsq_cox_snell(r.glm), 
+  #                  blr_rsq_nagelkerke(r.glm))
+  
   
   
   if(inherits(x, what="multinom")) modeltype <- "multinom"
